DiscoverBrand class

Matches Discover cards.

Rules: length 16-19 and prefix in 6011, 65, 644-649 or 622126-622925.

Inheritance

Constructors

DiscoverBrand()
Creates a DiscoverBrand.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
Human-readable brand name (used for error messages and debugging).
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

matches(String digits) bool
Returns true if digits matches this brand's prefix and length rules.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited