invalidType constant
String
const invalidType
Value provided to an array schema has the wrong type. Falls back to VCode.invalidType.
Implementation
static const invalidType = 'array.invalid_type';
Value provided to an array schema has the wrong type. Falls back to VCode.invalidType.
static const invalidType = 'array.invalid_type';