VDateCode class sealed

Error codes emitted by VDate and its validators.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

afterToday → const String
Date's y/m/d is not strictly after today.
age → const String
Age derived from date is outside the required range.
beforeToday → const String
Date's y/m/d is not strictly before today.
invalidType → const String
Value provided to a date schema has the wrong type. Falls back to VCode.invalidType.
isToday → const String
Date is not today (y/m/d comparison in local time).
notInRange → const String
Date is outside the allowed range.
required → const String
Date value is null. Falls back to VCode.required.
sameDay → const String
Date is not the same y/m/d as the reference date.
tooBig → const String
Date is after the maximum date.
tooSmall → const String
Date is before the minimum date.
weekday → const String
Date is not a weekday.
weekend → const String
Date is not a weekend.