licensePlate constant
String
const licensePlate
String is not a valid license plate for the given pattern.
Implementation
static const licensePlate = 'string.license_plate';
String is not a valid license plate for the given pattern.
static const licensePlate = 'string.license_plate';