defaultValue method
Sets a default value to use when the input is null.
Takes precedence over nullable: if both are set, the default is returned on null input.
V.string().defaultValue('N/A').parse(null); // 'N/A'
Implementation
VType<T> defaultValue(T value) {
_defaultValue = value;
_hasDefault = true;
return this;
}