VUnionCode class sealed

Error codes emitted by VUnion and its validators.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

invalid → const String
Value does not match any union option.
invalidType → const String
Value provided to a union schema has the wrong type. Falls back to VCode.invalidType.
required → const String
Union value is null. Falls back to VCode.required.