VArrayCode class sealed Internationalization
Error codes emitted by VArray and its validators.
See also:
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- containsAll → const String
- Array does not contain all required values.
- invalidType → const String
- Value provided to an array schema has the wrong type. Falls back to VCode.invalidType.
- required → const String
- Array value is null. Falls back to VCode.required.
- tooBig → const String
- Array has more elements than the maximum.
- tooSmall → const String
- Array has fewer elements than the minimum.
- unique → const String
- Array contains duplicate values.