VStringCode class sealed
Error codes emitted by VString and its validators.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- alpha → const String
- String contains non-letter characters.
- alphanumeric → const String
- String contains non-alphanumeric characters.
- base64 → const String
- String is not valid Base64.
- card → const String
- String is not a valid credit card number.
- contains → const String
- String does not contain the required substring.
- cvv → const String
- String is not a valid CVV.
- date → const String
- String is not a valid date representation — distinct from VDateCode which operates on DateTime values.
- domain → const String
- String is not a valid bare domain.
- email → const String
- String is not a valid email address.
- endsWith → const String
- String does not end with the required suffix.
- equals → const String
- String is not equal to the expected value.
- format → const String
- String does not match the expected format.
- hexColor → const String
- String is not a valid hex color.
- iban → const String
- String is not a valid IBAN.
- integer → const String
- String is not parseable as an integer.
- invalidType → const String
- Value provided to a string schema has the wrong type. Falls back to VCode.invalidType.
- ip → const String
- String is not a valid IP address.
- json → const String
- String is not valid JSON.
- jwt → const String
- String is not a valid JWT.
- length → const String
- String does not match the exact length.
- licensePlate → const String
- String is not a valid license plate for the given pattern.
- mac → const String
- String is not a valid MAC address.
- mongoId → const String
- String is not a valid MongoDB ObjectId.
- nanoId → const String
- String is not a valid NanoID.
- notEmpty → const String
- String must not be empty.
- numeric → const String
- String is not parseable as a finite number.
- password → const String
- String does not meet password requirements.
- phone → const String
- String is not a valid phone number.
- postalCode → const String
- String is not a valid postal code for the given pattern.
- required → const String
- String value is null. Falls back to VCode.required.
- semver → const String
- String is not a valid Semantic Version (SemVer).
- slug → const String
- String is not a valid slug.
- startsWith → const String
- String does not start with the required prefix.
- taxId → const String
- String is not a valid tax ID for the given pattern.
- time → const String
- String is not a valid time.
- tooBig → const String
- String exceeds the maximum length.
- tooSmall → const String
- String is shorter than the minimum length.
- ulid → const String
- String is not a valid ULID.
- url → const String
- String is not a valid URL.
- uuid → const String
- String is not a valid UUID.